#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_EPS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_EPS_HPP_INCLUDED

#include <nt2/ieee/include/functions/scalar/eps.hpp>

#endif
